starcluster.commands.downloadimage.CmdDownloadImage

Package starcluster :: Package commands :: Module downloadimage :: Class CmdDownloadImage |
[hide private]
[frames] | no frames]

# Class CmdDownloadImage

source code

    downloadimage [options] <image_id> <destination_directory>

    Download the manifest.xml and all AMI parts for an instance-store AMI

    Example:

        $ starcluster downloadimage ami-asdfasdf /data/myamis/ami-asdfasdf

Instance Methods | [hide private]
execute(self, args) | source code
Inherited from `completers.ImageCompleter` (private): `_completer` Inherited from `completers.Completer` (private): `_prep_for_completion` Inherited from `base.CmdBase`: `addopts`, `cancel_command`, `catch_ctrl_c`, `warn_experimental` Inherited from `base.CmdBase` (private): `_positive_int` Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| names = ``[``'``downloadimage``'``,` `'``di``'``]``
| bucket = `None` hash(x)
| image_name = `None` hash(x)
Inherited from `completers.Completer` (private): `_cfg` Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `completers.Completer`: `completer` Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict` Inherited from `object`: `__class__`